// 
// Decompiled by Procyon v0.5.30
// 

package org.cocos2dx.cpp;

import android.content.Context;
import android.content.pm.PackageManager;
import android.content.pm.Signature;
import android.content.res.Resources;
import android.util.Log;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

class GameHelperUtils
{
    private static final String[] FALLBACK_STRINGS;
    private static final int[] RES_IDS;
    public static final int R_APP_MISCONFIGURED = 2;
    public static final int R_LICENSE_FAILED = 3;
    public static final int R_SIGN_IN_FAILED = 1;
    public static final int R_UNKNOWN_ERROR = 0;
    
    static {
        FALLBACK_STRINGS = new String[] { "*Unknown error.", "*Failed to sign in. Please check your network connection and try again.", "*The application is incorrectly configured. Check that the package name and signing certificate match the client ID created in Developer Console. Also, if the application is not yet published, check that the account you are trying to sign in with is listed as a tester account. See logs for more information.", "*License check failed." };
        RES_IDS = new int[] { 2131165241, 2131165238, 2131165239, 2131165240 };
    }
    
    static String activityResponseCodeToString(final int n) {
        switch (n) {
            default: {
                return String.valueOf(n);
            }
            case -1: {
                return "RESULT_OK";
            }
            case 0: {
                return "RESULT_CANCELED";
            }
            case 10004: {
                return "RESULT_APP_MISCONFIGURED";
            }
            case 10005: {
                return "RESULT_LEFT_ROOM";
            }
            case 10003: {
                return "RESULT_LICENSE_FAILED";
            }
            case 10001: {
                return "RESULT_RECONNECT_REQUIRED";
            }
            case 10002: {
                return "SIGN_IN_FAILED";
            }
        }
    }
    
    static void byteToString(final StringBuilder sb, final byte b) {
        int n;
        if (b < 0) {
            n = b + 256;
        }
        else {
            n = b;
        }
        final int n2 = n / 16;
        final int n3 = n % 16;
        sb.append("0123456789ABCDEF".substring(n2, n2 + 1));
        sb.append("0123456789ABCDEF".substring(n3, n3 + 1));
    }
    
    static String errorCodeToString(final int n) {
        switch (n) {
            default: {
                return "Unknown error code " + n;
            }
            case 10: {
                return "DEVELOPER_ERROR(" + n + ")";
            }
            case 8: {
                return "INTERNAL_ERROR(" + n + ")";
            }
            case 5: {
                return "INVALID_ACCOUNT(" + n + ")";
            }
            case 11: {
                return "LICENSE_CHECK_FAILED(" + n + ")";
            }
            case 7: {
                return "NETWORK_ERROR(" + n + ")";
            }
            case 6: {
                return "RESOLUTION_REQUIRED(" + n + ")";
            }
            case 3: {
                return "SERVICE_DISABLED(" + n + ")";
            }
            case 9: {
                return "SERVICE_INVALID(" + n + ")";
            }
            case 1: {
                return "SERVICE_MISSING(" + n + ")";
            }
            case 2: {
                return "SERVICE_VERSION_UPDATE_REQUIRED(" + n + ")";
            }
            case 4: {
                return "SIGN_IN_REQUIRED(" + n + ")";
            }
            case 0: {
                return "SUCCESS(" + n + ")";
            }
        }
    }
    
    static String getAppIdFromResource(final Context context) {
        try {
            final Resources resources = context.getResources();
            return resources.getString(resources.getIdentifier("app_id", "string", context.getPackageName()));
        }
        catch (Exception ex) {
            ex.printStackTrace();
            return "??? (failed to retrieve APP ID)";
        }
    }
    
    static String getSHA1CertFingerprint(final Context context) {
        try {
            final Signature[] signatures = context.getPackageManager().getPackageInfo(context.getPackageName(), 64).signatures;
            if (signatures.length == 0) {
                return "ERROR: NO SIGNATURE.";
            }
            if (signatures.length > 1) {
                return "ERROR: MULTIPLE SIGNATURES";
            }
            final byte[] digest = MessageDigest.getInstance("SHA1").digest(signatures[0].toByteArray());
            final StringBuilder sb = new StringBuilder();
            for (int i = 0; i < digest.length; ++i) {
                if (i > 0) {
                    sb.append(":");
                }
                byteToString(sb, digest[i]);
            }
            return sb.toString();
        }
        catch (PackageManager.NameNotFoundException ex) {
            ex.printStackTrace();
            return "(ERROR: package not found)";
        }
        catch (NoSuchAlgorithmException ex2) {
            ex2.printStackTrace();
            return "(ERROR: SHA1 algorithm not found)";
        }
    }
    
    static String getString(final Context context, int n) {
        if (n < 0 || n >= GameHelperUtils.RES_IDS.length) {
            return null;
        }
        int n2 = 0;
        try {
            n2 = GameHelperUtils.RES_IDS[n];
            return context.getString(n2);
        } catch (Exception ex) {
            ex.printStackTrace();
            Log.w("GameHelper", "*** GameHelper could not found resource id #" + n2 + ". " + "This probably happened because you included it as a stand-alone JAR. " + "BaseGameUtils should be compiled as a LIBRARY PROJECT, so that it can access " + "its resources. Using a fallback string.");
            return GameHelperUtils.FALLBACK_STRINGS[n];
        }
    }
    
    static void printMisconfiguredDebugInfo(final Context context) {
        Log.w("GameHelper", "****");
        Log.w("GameHelper", "****");
        Log.w("GameHelper", "**** APP NOT CORRECTLY CONFIGURED TO USE GOOGLE PLAY GAME SERVICES");
        Log.w("GameHelper", "**** This is usually caused by one of these reasons:");
        Log.w("GameHelper", "**** (1) Your package name and certificate fingerprint do not match");
        Log.w("GameHelper", "****     the client ID you registered in Developer Console.");
        Log.w("GameHelper", "**** (2) Your App ID was incorrectly entered.");
        Log.w("GameHelper", "**** (3) Your game settings have not been published and you are ");
        Log.w("GameHelper", "****     trying to log in with an account that is not listed as");
        Log.w("GameHelper", "****     a test account.");
        Log.w("GameHelper", "****");
        if (context == null) {
            Log.w("GameHelper", "*** (no Context, so can't print more debug info)");
            return;
        }
        Log.w("GameHelper", "**** To help you debug, here is the information about this app");
        Log.w("GameHelper", "**** Package name         : " + context.getPackageName());
        Log.w("GameHelper", "**** Cert SHA1 fingerprint: " + getSHA1CertFingerprint(context));
        Log.w("GameHelper", "**** App ID from          : " + getAppIdFromResource(context));
        Log.w("GameHelper", "****");
        Log.w("GameHelper", "**** Check that the above information matches your setup in ");
        Log.w("GameHelper", "**** Developer Console. Also, check that you're logging in with the");
        Log.w("GameHelper", "**** right account (it should be listed in the Testers section if");
        Log.w("GameHelper", "**** your project is not yet published).");
        Log.w("GameHelper", "****");
        Log.w("GameHelper", "**** For more information, refer to the troubleshooting guide:");
        Log.w("GameHelper", "****   http://developers.google.com/games/services/android/troubleshooting");
    }
}
